<?php
//
// +----------------------------------------------------------------------+
// | PEAR :: XML :: Transformer                                           |
// +----------------------------------------------------------------------+
// | Copyright (c) 2002 Sebastian Bergmann <sb@sebastian-bergmann.de> and |
// |                    Kristian Khntopp <kris@koehntopp.de>.            |
// +----------------------------------------------------------------------+
// | This source file is subject to version 3.00 of the PHP License,      |
// | that is available at http://www.php.net/license/3_0.txt.             |
// | If you did not receive a copy of the PHP license and are unable to   |
// | obtain it through the world-wide-web, please send a note to          |
// | license@php.net so we can mail you a copy immediately.               |
// +----------------------------------------------------------------------+
//
// $Id: OutputBuffer.php,v 1.1 2002/09/18 07:24:34 sebastian Exp $
//

require_once 'XML/Transformer.php';

/**
* ...
*
* Example
*
*   <?php
*   require_once 'XML/Transformer.php';
*
*   $t = new XML_Transformer(
*     array(
*       'overloadedElements' => array(
*         'bold' => array(
*           'start' => 'startElementBold',
*           'end'   => 'endElementBold'
*         )
*       )
*     )
*   );
*
*   function startElementBold($attributes) {
*     return '<b>';
*   }
*
*   function endElementBold($cdata) {
*     return $cdata . '</b>';
*   }
*   ?>
*   <bold>text</bold>
*
* Output
*
*   <b>text</b>
*
* @author  Sebastian Bergmann <sb@sebastian-bergmann.de>
*          Kristian Khntopp <kris@koehntopp.de>
* @version $Revision: 1.1 $
* @access  public
*/
class XML_Transformer_OutputBuffer extends XML_Transformer {
    // {{{ Members

    /**
    * @var    boolean
    * @access private
    */
    var $_started = false;

    // }}}
    // {{{ function XML_Transformer_OutputBuffer($parameters = array())

    /**
    * Constructor.
    *
    * @param  array
    * @access public
    */
    function XML_Transformer_OutputBuffer($parameters = array()) {
        $this->XML_Transformer($parameters);

        if (!empty($this->_callbackRegistry->overloadedElements) ||
            !empty($this->_callbackRegistry->overloadedNamespaces)) {
            $this->start();
        }
    }

    // }}}
    // {{{ function start()

    /**
    * Starts the output-buffering,
    * and thus the transformation.
    *
    * @access public
    */
    function start() {
        if (!$this->_started) {
            ob_start(
              array(
                $this, 'transform'
              )
            );

            $this->_started = true;

            $this->_debug(
              'start: ' . serialize($this)
            );
        }
    }

    // }}}
}

/*
 * vim600:  et sw=2 ts=2 fdm=marker
 * vim<600: et sw=2 ts=2
 */
?>
